#!/bin/sh
echo 'name: optparse-applicative
version: 0.5.2.1
id: optparse-applicative-0.5.2.1-5a0577cc36855c6b7e4f384fbdbdc6bc

license: BSD3
copyright: (c) 2012  Paolo Capriotti <p.capriotti@gmail.com>
maintainer: p.capriotti@gmail.com
stability:
homepage: https://github.com/pcapriotti/optparse-applicative
package-url:
synopsis: Utilities and combinators for parsing command line options
description: Here is a simple example of an applicative option parser:
             .
             @
             data Sample = Sample
             &#x20; &#x7b; hello :: String
             &#x20; , quiet :: Bool &#x7d;
             .
             sample :: Parser Sample
             sample = Sample
             &#x20; \<$\> strOption
             &#x20;     ( long \"hello\"
             &#x20;     & metavar \"TARGET\"
             &#x20;     & help \"Target for the greeting\" )
             &#x20; \<*\> switch
             &#x20;     ( long \"quiet\"
             &#x20;     & help \"Whether to be quiet\" )
             @
             .
             The parser is built using applicative style starting from a set of basic
             combinators. In this example, @hello@ is defined as an '\''option'\'' with a
             @String@ argument, while @quiet@ is a boolean '\''flag'\'' (called '\''switch'\'').
             .
             A parser can be used like this:
             .
             @
             greet :: Sample -> IO ()
             greet (Sample h False) = putStrLn $ \"Hello, \" ++ h
             greet _ = return ()
             .
             main :: IO ()
             main = execParser opts \>\>= greet
             &#x20; where
             &#x20;   opts = info (helper \<*\> sample)
             &#x20;     ( fullDesc
             &#x20;     & progDesc \"Print a greeting for TARGET\"
             &#x20;     & header \"hello - a test for optparse-applicative\" )
             @
             .
             The @greet@ function is the entry point of the program, while @opts@ is a
             complete description of the program, used when generating a help text. The
             '\''helper'\'' combinator takes any parser, and adds a @help@ option to it (which
             always fails).
             .
             The @hello@ option in this example is mandatory (since it doesn'\''t have a
             default value), so running the program without any argument will display a
             help text:
             .
             >hello - a test for optparse-applicative
             >
             >Usage: hello --hello TARGET [--quiet]
             >  Print a greeting for TARGET
             >
             >Available options:
             >  -h,--help                Show this help text
             >  --hello TARGET           Target for the greeting
             >  --quiet                  Whether to be quiet
             .
             containing a short usage summary, and a detailed list of options with
             descriptions.
category: System
author: Paolo Capriotti
exposed: True
exposed-modules: Options.Applicative Options.Applicative.Arrows
                 Options.Applicative.BashCompletion Options.Applicative.Builder
                 Options.Applicative.Builder.Arguments
                 Options.Applicative.Builder.Completer
                 Options.Applicative.Builder.Internal Options.Applicative.Common
                 Options.Applicative.Extra Options.Applicative.Help
                 Options.Applicative.Types Options.Applicative.Utils
hidden-modules: Options.Applicative.Internal
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/optparse-applicative-0.5.2.1
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/optparse-applicative-0.5.2.1
              /usr/local/lib
hs-libraries: HSoptparse-applicative-0.5.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-2324e29e8f7c561043683fccde7728aa
         process-1.1.0.2-a830d25f0e9fb9c610aa641b7f5b20f9
         transformers-0.3.0.0-948c0bbaafc952a144be4248ffa27cb1
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/optparse-applicative-0.5.2.1/html/optparse-applicative.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/optparse-applicative-0.5.2.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
